@@ -5,10 +5,11 @@ Imports the various compute backends
 from typing import Set
 
 from ..exceptions import InputError, ResourceError
+from .model import ProgramHarness
 from .adcc import AdccHarness
 from .cfour import CFOURHarness
 from .dftd3 import DFTD3Harness
-from .dftd4 import DFTD4Harness
+from .dftd_ng import DFTD4Harness, SDFTD3Harness
 from .gamess import GAMESSHarness
 from .gcp import GCPHarness, MCTCGCPHarness
 from .molpro import MolproHarness
@@ -22,6 +23,7 @@ from .qchem import QChemHarness
 from .qcore import EntosHarness, QcoreHarness
 from .rdkit import RDKitHarness
 from .terachem import TeraChemHarness
+from .terachem_frontend import TeraChemFrontEndHarness
 from .terachem_pbs import TeraChemPBSHarness
 from .torchani import TorchANIHarness
 from .turbomole import TurbomoleHarness
@@ -32,7 +34,7 @@ __all__ = ["register_program", "get_program", "list_all_programs", "list_availab
 programs = {}
 
 
-def register_program(entry_point: "ProgramHarness") -> None:
+def register_program(entry_point: ProgramHarness) -> None:
     """
     Register a new ProgramHarness with QCEngine.
     """
@@ -54,7 +56,7 @@ def unregister_program(name: str) -> None:
         raise KeyError(f"Program {name} is not registered with QCEngine")
 
 
-def get_program(name: str, check: bool = True) -> "ProgramHarness":
+def get_program(name: str, check: bool = True) -> ProgramHarness:
     """
     Returns a program's executor class
 
@@ -114,6 +116,7 @@ register_program(QChemHarness())
 register_program(QcoreHarness())
 register_program(TeraChemHarness())
 register_program(TurbomoleHarness())
+register_program(TeraChemFrontEndHarness())
 register_program(TeraChemPBSHarness())
 
 # Semi-empirical
@@ -130,6 +133,7 @@ register_program(OpenMMHarness())
 # Analytical Corrections
 register_program(DFTD3Harness())
 register_program(DFTD4Harness())
+register_program(SDFTD3Harness())
 register_program(GCPHarness())
 register_program(MCTCGCPHarness())
 register_program(MP2DHarness())
