@@ -2,6 +2,7 @@
 
 import collections
 import copy
+from typing import Dict, List, Optional, Union
 
 from ..exceptions import InputError
 
@@ -44,9 +45,22 @@ dashcoeff = {
             "core-dsd-blyp": {"params": {"s6": 0.41, "alpha6": 60.0, "sr6": 1.1}},
         },
     },
-    "d3zero": {
+    "d3zeroatm": {
+        "formal": "D3ATM",
+        "alias": [],
+        "description": "    Grimme's -D3 (zero-damping) Dispersion Correction with ATM",
+        "citation": "    Grimme S.; Antony J.; Ehrlich S.; Krieg H. (2010), J. Chem. Phys., 132: 154104\n",
+        "bibtex": "Grimme:2010:154104",
+        "default": collections.OrderedDict(
+            [("s6", 1.0), ("s8", 0.0), ("sr6", 1.0), ("alpha6", 14.0), ("sr8", 1.0), ("s9", 1.0)]
+        ),
+        "definitions": {
+            # D3 parameters loaded from d3zero2b and from authoritative source below and s9 parameter added
+        },
+    },
+    "d3zero2b": {
         "formal": "D3",
-        "alias": ["d3"],
+        "alias": ["d3", "d3zero", "d32b"],
         "description": "    Grimme's -D3 (zero-damping) Dispersion Correction",
         "citation": "    Grimme S.; Antony J.; Ehrlich S.; Krieg H. (2010), J. Chem. Phys., 132: 154104\n",
         "bibtex": "Grimme:2010:154104",
@@ -348,9 +362,20 @@ dashcoeff = {
             "hf": {"params": {"s6": 1.0, "s8": 1.746, "sr6": 1.158, "alpha6": 14.0, "sr8": 1.000}},
         },
     },
-    "d3bj": {
-        "formal": "D3(BJ)",
+    "d3bjatm": {
+        "formal": "D3(BJ)ATM",
         "alias": [],
+        "description": "    Grimme's -D3 (BJ-damping) Dispersion Correction with ATM",
+        "citation": "    Grimme S.; Ehrlich S.; Goerigk L. (2011), J. Comput. Chem., 32: 1456\n",
+        "bibtex": "Grimme:2011:1456",
+        "default": collections.OrderedDict([("s6", 1.0), ("s8", 1.0), ("a1", 0.0), ("a2", 1.0), ("s9", 1.0)]),
+        "definitions": {
+            # D3 parameters loaded from d3bj2b and from authoritative source below and s9 parameter added
+        },
+    },
+    "d3bj2b": {
+        "formal": "D3(BJ)",
+        "alias": ["d3bj"],
         "description": "    Grimme's -D3 (BJ-damping) Dispersion Correction",
         "citation": "    Grimme S.; Ehrlich S.; Goerigk L. (2011), J. Comput. Chem., 32: 1456\n",
         "bibtex": "Grimme:2011:1456",
@@ -620,9 +645,21 @@ dashcoeff = {
             "core-dsd-blyp": {"params": {"s6": 0.500, "s8": 0.2130, "a1": 0.0000, "a2": 6.0519}},
         },
     },
-    "d3mzero": {
+    "d3mzeroatm": {
+        "formal": "D3MATM",
+        "alias": [],
+        "description": "    Grimme's -D3 (zero-damping, short-range refitted) Dispersion Correction with ATM",
+        "citation": "    Grimme S.; Antony J.; Ehrlich S.; Krieg H. (2010), J. Chem. Phys., 132: 154104\n"
+        + "    Smith, D. G. A.; Burns, L. A.; Patkowski, K.; Sherrill, C. D. (2016), J. Phys. Chem. Lett.; 7: 2197\n",
+        "bibtex": "Grimme:2010:154104",
+        "default": collections.OrderedDict([("s6", 1.0), ("s8", 1.0), ("sr6", 1.0), ("beta", 1.0), ("s9", 1.0)]),
+        "definitions": {
+            # D3 parameters loaded from d3mzero2b and from authoritative source below and s9 parameter added
+        },
+    },
+    "d3mzero2b": {
         "formal": "D3M",
-        "alias": ["d3m"],
+        "alias": ["d3m", "d3mzero", "d3m2b"],
         "description": "    Grimme's -D3 (zero-damping, short-range refitted) Dispersion Correction",
         "citation": "    Grimme S.; Antony J.; Ehrlich S.; Krieg H. (2010), J. Chem. Phys., 132: 154104\n"
         + "    Smith, D. G. A.; Burns, L. A.; Patkowski, K.; Sherrill, C. D. (2016), J. Phys. Chem. Lett.; 7: 2197\n",
@@ -641,9 +678,21 @@ dashcoeff = {
             "hf": {"params": {"s6": 1.000, "s8": 0.885517, "sr6": 1.383214, "beta": 0.075488}},  # JBS 01/2021
         },
     },
-    "d3mbj": {
-        "formal": "D3M(BJ)",
+    "d3mbjatm": {
+        "formal": "D3M(BJ)ATM",
         "alias": [],
+        "description": "    Grimme's -D3 (BJ-damping, short-range refitted) Dispersion Correction with ATM",
+        "citation": "    Grimme S.; Ehrlich S.; Goerigk L. (2011), J. Comput. Chem., 32: 1456\n"
+        + "    Smith, D. G. A.; Burns, L. A.; Patkowski, K.; Sherrill, C. D. (2016), J. Phys. Chem. Lett.; 7: 2197\n",
+        "bibtex": "Grimme:2011:1456",
+        "default": collections.OrderedDict([("s6", 1.0), ("s8", 1.0), ("a1", 1.0), ("a2", 1.0), ("s9", 1.0)]),
+        "definitions": {
+            # D3 parameters loaded from d3mbj2b and from authoritative source below and s9 parameter added
+        },
+    },
+    "d3mbj2b": {
+        "formal": "D3M(BJ)",
+        "alias": ["d3mbj"],
         "description": "    Grimme's -D3 (BJ-damping, short-range refitted) Dispersion Correction",
         "citation": "    Grimme S.; Ehrlich S.; Goerigk L. (2011), J. Comput. Chem., 32: 1456\n"
         + "    Smith, D. G. A.; Burns, L. A.; Patkowski, K.; Sherrill, C. D. (2016), J. Phys. Chem. Lett.; 7: 2197\n",
@@ -662,6 +711,35 @@ dashcoeff = {
             "hf": {"params": {"s6": 1.000, "s8": 0.713190, "a1": 0.079541, "a2": 3.627854}},  # JBS 01/2021
         },
     },
+    "d3opatm": {
+        "formal": "D3(op)ATM",
+        "alias": [],
+        "description": "    D3 dispersion correction with optimized power damping function with ATM. Based on rational damping function and additional zero-damping like power function.",
+        "citation": "    S. Grimme, S. Ehrlich, and L. Goerigk., Comput. Chem., 32:1456–1465, 2011. doi:10.1002/jcc.21759.\n"
+        + "    Jonathon Witte, Narbe Mardirossian, Jeffrey B Neaton, and Martin Head-Gordon., J. Chem. Theory Comput., 13(5):2043–2052, 2017. doi:10.1021/acs.jctc.7b00176.\n",
+        "bibtex": "Grimme:2011:1456",
+        "default": collections.OrderedDict(
+            [("s6", 1.0), ("s8", 1.0), ("a1", 1.0), ("a2", 1.0), ("beta", 0.0), ("s9", 1.0)]
+        ),
+        "definitions": {
+            # D3 parameters loaded from d3op2b and from authoritative source below and s9 parameter added
+        },
+    },
+    "d3op2b": {
+        "formal": "D3(op)",
+        "alias": ["d3op"],
+        "description": "    D3 dispersion correction with optimized power damping function. Based on rational damping function and additional zero-damping like power function.",
+        "citation": "    S. Grimme, S. Ehrlich, and L. Goerigk., Comput. Chem., 32:1456–1465, 2011. doi:10.1002/jcc.21759.\n"
+        + "    Jonathon Witte, Narbe Mardirossian, Jeffrey B Neaton, and Martin Head-Gordon., J. Chem. Theory Comput., 13(5):2043–2052, 2017. doi:10.1021/acs.jctc.7b00176.\n",
+        "bibtex": "Grimme:2011:1456",
+        "default": collections.OrderedDict(
+            [("s6", 1.0), ("s8", 1.0), ("a1", 1.0), ("a2", 1.0), ("beta", 0.0)],
+        ),
+        "definitions": {
+            # will be loaded later
+            # From https://github.com/dftd3/simple-dftd3/blob/main/assets/parameters.toml
+        },
+    },
     "nl": {
         "formal": "NL",
         "alias": [],
@@ -814,6 +892,15 @@ dashcoeff = {
 }
 
 
+# for d3*atm, only skeleton entries with metadata defined above. below copies in parameters from d3*2b
+for d in ["d3zero", "d3bj", "d3mzero", "d3mbj", "d3op"]:
+    for k, v in dashcoeff[d + "2b"]["definitions"].items():
+        dashcoeff[d + "atm"]["definitions"][k] = copy.deepcopy(dashcoeff[d + "2b"]["definitions"][k])
+        dashcoeff[d + "atm"]["definitions"][k]["params"][
+            "s9"
+        ] = 1.0  # set twice: this one adds s9 to the params list for atm
+
+
 def _get_d4bj_definitions() -> dict:
     """DFTD4 provides access to damping parameters on per functional basis.
     But we want all of them.
@@ -821,6 +908,8 @@ def _get_d4bj_definitions() -> dict:
     We let DFTD4 take care of finding and loading the parameter file,
     but to get all parameters, we implement the logic to read those
     parameters ourselves again.
+
+    This method is upstreamed in dftd4 >3.3.0 and could be replaced in the future.
     """
 
     try:
@@ -880,6 +969,65 @@ def _get_d4bj_definitions() -> dict:
 
 dashcoeff["d4bjeeqatm"]["definitions"].update(_get_d4bj_definitions())
 
+try:
+
+    def _get_d3_definitions(dashlevel: str) -> dict:
+        """
+        Lucky for us dftd3 provides access to all damping parameters directly.
+
+        However, we are not happy with the structure of the dict and
+        therefore do some restructuring. The below solution tries to bend
+        the data returned by dftd3 into the right shape to make qcng happy.
+        """
+
+        from dftd3.parameters import get_all_damping_params
+
+        # The names here are the subset allowed by qcng with the names used in dftd3
+        allowed = {
+            "bj": ["a1", "a2", "s6", "s8", "s9"],
+            "zero": ["rs6", "rs8", "alp", "s6", "s8", "s9"],
+            "mbj": ["a1", "a2", "s6", "s8", "s9"],
+            "mzero": ["rs6", "rs8", "alp", "s6", "s8", "bet", "s9"],
+            "op": ["a1", "a2", "s6", "s8", "bet", "s9"],
+        }
+        # mapping from dftd3 to qcng names, also, we have to reverse it later again
+        rename = {
+            "rs6": "sr6",
+            "rs8": "sr8",
+            "alp": "alpha6",
+            "bet": "beta",
+        }
+
+        # FIXME: dict comprehension at its finest
+        #
+        # 1. insert an additional level each method
+        # 2. filter parameter names accepted by qcng
+        # 3. map from dftd3 to qcng names
+        # 4. return the whole mess
+        return {
+            key: {
+                "params": {
+                    rename.get(param, param): value for param, value in params.items() if param in allowed[dashlevel]
+                }
+            }
+            for key, params in get_all_damping_params([dashlevel]).items()
+        }
+
+    dashcoeff["d3bjatm"]["definitions"].update(_get_d3_definitions("bj"))
+    dashcoeff["d3zeroatm"]["definitions"].update(_get_d3_definitions("zero"))
+    dashcoeff["d3mbjatm"]["definitions"].update(_get_d3_definitions("mbj"))
+    dashcoeff["d3mzeroatm"]["definitions"].update(_get_d3_definitions("mzero"))
+    dashcoeff["d3opatm"]["definitions"].update(_get_d3_definitions("op"))
+
+    for d in ["d3zero", "d3bj", "d3mzero", "d3mbj", "d3op"]:
+        for k, v in dashcoeff[d + "atm"]["definitions"].items():
+            dashcoeff[d + "atm"]["definitions"][k]["params"][
+                "s9"
+            ] = 1.0  # set twice: this one establishes 1.0 if upstream is still 0.0 (pre v0.7.0 simple-dftd3)
+
+except ModuleNotFoundError:
+    pass
+
 
 def get_dispersion_aliases():
     """Returns dict where keys are all (lowercased) strings that are
@@ -897,7 +1045,13 @@ def get_dispersion_aliases():
     return alias
 
 
-def from_arrays(name_hint=None, level_hint=None, param_tweaks=None, dashcoeff_supplement=None, verbose=1):
+def from_arrays(
+    name_hint: Optional[str] = None,
+    level_hint: Optional[str] = None,
+    param_tweaks: Union[List[float], Dict[str, float]] = None,
+    dashcoeff_supplement: Optional[Dict[str, Dict]] = None,
+    verbose: int = 1,
+):
     """Use the three paths of empirical dispersion parameter information
     (DFT functional, dispersion correction level, and particular
     parameters) to populate the parameter array and validate a
@@ -905,27 +1059,27 @@ def from_arrays(name_hint=None, level_hint=None, param_tweaks=None, dashcoeff_su
 
     Parameters
     ----------
-    name_hint : str, optional
+    name_hint
         Name of functional (func only, func & disp, or disp only) for
         which to compute dispersion (e.g., blyp, BLYP-D2, blyp-d3bj,
         blyp-d3(bj), hf+d). Any or all parameters initialized from
         `dashcoeff[dashlevel][functional-without-dashlevel]` or
         `dashcoeff_supplement[dashlevel][functional-with-dashlevel]
         can be overwritten via `param_tweaks`.
-    level_hint : str, optional
+    level_hint
         Name of dispersion correction to be applied (e.g., d, D2,
         d3(bj), das2010). Must be key in `dashcoeff` or "alias" or
         "formal" to one.
-    param_tweaks : list or dict, optional
+    param_tweaks
         Values for the same keys as `dashcoeff[dashlevel]['default']`
         (and same order if list) used to override any or all values
         initialized by `name_hint`.  Extra parameters will error.
-    dashcoeff_supplement: dict, optional
+    dashcoeff_supplement
         Dictionary of the same structure as `dashcoeff` that contains
         in "definitions" field full functional names, rather than
         fctl less dashlvl. Used to validate dict_builder fctls with
         dispersion or identify disp level from just `name_hint`.
-    verbose : int, optional
+    verbose
         Amount of printing.
 
     Returns
@@ -933,7 +1087,7 @@ def from_arrays(name_hint=None, level_hint=None, param_tweaks=None, dashcoeff_su
     dict
         Metadata defining dispersion calculation.
 
-        dashlevel : {'d1', 'd2', 'd3zero', 'd3bj', 'd3mzero', 'd3mbj', 'chg', 'das2009', 'das2010', 'nl', "d4bjeeqatm"}
+        dashlevel : {'d1', 'd2', 'd3zero2b', 'd3bj2b', 'd3mzero2b', 'd3mbj2b', 'd3op2b', 'd3zeroatm', 'd3bjatm', 'd3mzeroatm', 'd3mbjatm', 'd3opatm', 'chg', 'das2009', 'das2010', 'nl', "d4bjeeqatm"}
             Name (de-aliased, de-formalized, lowercase) of dispersion
             correction -- atom data, dispersion model, damping functional
             form -- to be applied. Resolved from `name_hint` and/or
@@ -962,14 +1116,45 @@ def from_arrays(name_hint=None, level_hint=None, param_tweaks=None, dashcoeff_su
     * Function intended to be idempotent.
 
     """
+    try:
+        # try/except block retrofits Psi4 for pre-2b/atm-split in dashcoeff
+        import psi4
+
+        if "d3bj" in psi4.procrouting.empirical_dispersion._engine_can_do["dftd3"]:
+            psi4.procrouting.empirical_dispersion._engine_can_do["dftd3"] = [
+                "d2",
+                "d3zero2b",
+                "d3bj2b",
+                "d3mzero2b",
+                "d3mbj2b",
+            ]
+            for d in ["d3zero", "d3bj", "d3mzero", "d3mbj"]:
+                psi4.procrouting.empirical_dispersion._capable_engines_for_disp[
+                    d + "2b"
+                ] = psi4.procrouting.empirical_dispersion._capable_engines_for_disp.pop(d)
+    except ImportError:
+        pass
+
     if verbose > 1:
-        print("dftd3.from_arrays HINTS:", name_hint, level_hint, param_tweaks, bool(dashcoeff_supplement))
+        print(
+            "empirical_dispersion_resources.from_arrays HINTS:",
+            name_hint,
+            level_hint,
+            param_tweaks,
+            bool(dashcoeff_supplement),
+        )
 
     # << 0 >> prep
     if dashcoeff_supplement is not None:
         supplement_dashlevel_lookup = {}
-        for disp, ddisp in dashcoeff_supplement.items():
+        for disp, ddisp in dashcoeff_supplement.copy().items():
             for func, params in ddisp["definitions"].items():
+                try:
+                    dashcoeff[disp]
+                except KeyError:
+                    # try/except block accommodates dashcoeff_supplement from pre-2b/atm-split in dashcoeff
+                    disp = get_dispersion_aliases()[disp]
+                    dashcoeff_supplement[disp] = ddisp
                 if params["params"].keys() != dashcoeff[disp]["default"].keys():
                     if verbose > 2:
                         print(
@@ -1142,7 +1327,7 @@ def from_arrays(name_hint=None, level_hint=None, param_tweaks=None, dashcoeff_su
 
     if verbose > 1:
         print(
-            f"dftd3.from_arrays RESOLVED: dashlevel={dashleveleff}, dashparams={disp_params}, fctldash={fctldasheff}, dashparams_citation={citeff}"
+            f"empirical_dispersion_resources.from_arrays RESOLVED: dashlevel={dashleveleff}, dashparams={disp_params}, fctldash={fctldasheff}, dashparams_citation={citeff}"
         )
 
     return {
