@@ -188,13 +188,13 @@ def test_mopac_task():
     }
 
     ret = qcng.compute(input_data, "mopac", raise_error=True)
-    assert ret.extras.keys() >= {"heat_of_formation", "energy_electronic", "dip_vec"}
+    assert ret.extras.keys() >= {"heat_of_formation", "dip_vec"}
     energy = pytest.approx(-0.08474117913025125, rel=1.0e-5)
 
     # Check gradient
     ret = qcng.compute(input_data, "mopac", raise_error=True)
-    assert ret.extras.keys() >= {"heat_of_formation", "energy_electronic", "dip_vec"}
-    assert np.linalg.norm(ret.return_result) == pytest.approx(0.03543560156912385, rel=1.0e-4)
+    assert ret.extras.keys() >= {"heat_of_formation", "dip_vec"}
+    assert np.linalg.norm(ret.return_result) == pytest.approx(0.03543560156912385, rel=3.0e-4)
     assert ret.properties.return_energy == energy
 
     # Check energy
@@ -220,12 +220,12 @@ def test_random_failure_no_retries(failure_engine):
 def test_random_failure_with_retries(failure_engine):
 
     failure_engine.iter_modes = ["random_error", "random_error", "random_error"]
-    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, local_options={"retries": 2})
+    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, task_config={"retries": 2})
     assert ret.input_data["provenance"]["retries"] == 2
     assert ret.error.error_type == "random_error"
 
     failure_engine.iter_modes = ["random_error", "input_error"]
-    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, local_options={"retries": 4})
+    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, task_config={"retries": 4})
     assert ret.input_data["provenance"]["retries"] == 1
     assert ret.error.error_type == "input_error"
 
@@ -234,7 +234,7 @@ def test_random_failure_with_success(failure_engine):
 
     failure_engine.iter_modes = ["random_error", "pass"]
     failure_engine.ncalls = 0
-    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, local_options={"retries": 1})
+    ret = qcng.compute(failure_engine.get_job(), failure_engine.name, raise_error=False, task_config={"retries": 1})
 
     assert ret.success, ret.error.error_message
     assert ret.provenance.retries == 1
