@@ -3,7 +3,7 @@ Tests the DQM compute dispatch module
 """
 
 import pytest
-from qcelemental.models import DriverEnum, OptimizationInput
+from qcelemental.models import DriverEnum, OptimizationInput, FailedOperation
 from qcelemental.models.common_models import Model
 from qcelemental.models.procedures import OptimizationSpecification, QCInputSpecification, TDKeywords, TorsionDriveInput
 
@@ -48,7 +48,8 @@ def test_geometric_psi4(input_data, optimizer):
     # Check keywords passing
     for single in ret.trajectory:
         assert "scf_properties" in single.keywords
-        assert "WIBERG_LOWDIN_INDICES" in single.extras["qcvars"]
+        assert "WIBERG_LOWDIN_INDICES" in single.extras["qcvars"] or "WIBERG LOWDIN INDICES" in single.extras["qcvars"]
+        # TODO: old WIBERG qcvar used underscore; new one uses space. covering bases here but remove someday
 
 
 @using("psi4")
@@ -100,6 +101,23 @@ def test_berny_stdout(input_data):
     assert "All criteria matched" in ret.stdout
 
 
+@using("psi4")
+@using("berny")
+def test_berny_failed_gradient_computation(input_data):
+
+    input_data["initial_molecule"] = qcng.get_molecule("water")
+    input_data["input_specification"]["model"] = {"method": "HF", "basis": "sto-3g"}
+    input_data["input_specification"]["keywords"] = {"badpsi4key": "badpsi4value"}
+    input_data["keywords"]["program"] = "psi4"
+
+    input_data = OptimizationInput(**input_data)
+
+    ret = qcng.compute_procedure(input_data, "berny", raise_error=False)
+    assert isinstance(ret, FailedOperation)
+    assert ret.success is False
+    assert ret.error.error_type == qcng.exceptions.InputError.error_type
+
+
 @using("geometric")
 @using("rdkit")
 def test_geometric_rdkit_error(input_data):
@@ -135,7 +153,6 @@ def test_optimization_protocols(input_data):
 
 
 @using("geometric")
-@using("rdkit")
 def test_geometric_retries(failure_engine, input_data):
 
     failure_engine.iter_modes = ["random_error", "pass", "random_error", "random_error", "pass"]  # Iter 1  # Iter 2
@@ -147,10 +164,11 @@ def test_geometric_retries(failure_engine, input_data):
     }
     input_data["input_specification"]["model"] = {"method": "something"}
     input_data["keywords"]["program"] = failure_engine.name
+    input_data["keywords"]["coordsys"] = "cart"  # needed by geometric v1.0 to play nicely with failure_engine
 
     input_data = OptimizationInput(**input_data)
 
-    ret = qcng.compute_procedure(input_data, "geometric", local_options={"ncores": 13}, raise_error=True)
+    ret = qcng.compute_procedure(input_data, "geometric", task_config={"ncores": 13}, raise_error=True)
     assert ret.success is True
     assert ret.trajectory[0].provenance.retries == 1
     assert ret.trajectory[0].provenance.ncores == 13
@@ -160,7 +178,7 @@ def test_geometric_retries(failure_engine, input_data):
 
     # Ensure we still fail
     failure_engine.iter_modes = ["random_error", "pass", "random_error", "random_error", "pass"]  # Iter 1  # Iter 2
-    ret = qcng.compute_procedure(input_data, "geometric", local_options={"ncores": 13, "retries": 1})
+    ret = qcng.compute_procedure(input_data, "geometric", task_config={"ncores": 13, "retries": 1})
     assert ret.success is False
     assert ret.input_data["trajectory"][0]["provenance"]["retries"] == 1
     assert len(ret.input_data["trajectory"]) == 2
@@ -194,7 +212,7 @@ def test_geometric_retries(failure_engine, input_data):
         pytest.param(
             "mopac",
             {"method": "PM6"},
-            [1.7927843431811934, 2.893333237502448, 107.60441967992045],
+            [1.793052302291527, 2.893333237502448, 107.57254391453196],
             marks=using("mopac"),
         ),
         pytest.param(
@@ -299,8 +317,8 @@ def test_torsiondrive_generic():
         optimization_spec=OptimizationSpecification(
             procedure="geomeTRIC",
             keywords={
-                "coordsys": "dlc",
-                "maxiter": 300,
+                "coordsys": "tric",
+                "maxiter": 500,
                 "program": "rdkit",
             },
         ),
@@ -329,3 +347,29 @@ def test_torsiondrive_generic():
     assert ret.optimization_history["180"][0].trajectory[0].provenance.creator.lower() == "rdkit"
 
     assert ret.stdout == "All optimizations converged at lowest energy. Job Finished!\n"
+
+
+@using("mrchem")
+@pytest.mark.parametrize(
+    "optimizer",
+    [
+        pytest.param("geometric", marks=using("geometric")),
+        pytest.param("optking", marks=using("optking")),
+        pytest.param("berny", marks=using("berny")),
+    ],
+)
+def test_optimization_mrchem(input_data, optimizer):
+
+    input_data["initial_molecule"] = qcng.get_molecule("hydrogen")
+    input_data["input_specification"]["model"] = {"method": "HF"}
+    input_data["input_specification"]["keywords"] = {"world_prec": 1.0e-4}
+    input_data["keywords"]["program"] = "mrchem"
+
+    input_data = OptimizationInput(**input_data)
+
+    ret = qcng.compute_procedure(input_data, optimizer, raise_error=True)
+    assert 10 > len(ret.trajectory) > 1
+
+    assert pytest.approx(ret.final_molecule.measure([0, 1]), 1.0e-3) == 1.3860734486984705
+    assert ret.provenance.creator.lower() == optimizer
+    assert ret.trajectory[0].provenance.creator.lower() == "mrchem"
