@@ -18,8 +18,8 @@ from pathlib import Path
 from threading import Thread
 from typing import Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Union
 
-from pydantic import ValidationError
-from qcelemental.models import FailedOperation
+from pydantic import BaseModel, ValidationError
+from qcelemental.models import AtomicResult, FailedOperation, OptimizationResult
 
 from qcengine.config import TaskConfig
 
@@ -54,7 +54,7 @@ def create_mpi_invocation(executable: str, task_config: TaskConfig) -> List[str]
     return command
 
 
-def model_wrapper(input_data: Dict[str, Any], model: "BaseModel") -> "BaseModel":
+def model_wrapper(input_data: Dict[str, Any], model: BaseModel) -> BaseModel:
     """
     Wrap input data in the given model, or return a controlled error
     """
@@ -142,17 +142,23 @@ def compute_wrapper(capture_output: bool = True, raise_error: bool = False) -> D
 
 
 def handle_output_metadata(
-    output_data: Union[Dict[str, Any], "BaseModel"],
+    output_data: Union[Dict[str, Any], "AtomicResult", "OptimizationResult", "FailedOperation"],
     metadata: Dict[str, Any],
     raise_error: bool = False,
     return_dict: bool = True,
-) -> Union[Dict[str, Any], "BaseModel"]:
+) -> Union[Dict[str, Any], "AtomicResult", "OptimizationResult", "FailedOperation"]:
     """
     Fuses general metadata and output together.
 
+    Parameters:
+        output_data: The original output object to be fused with metadata
+        metadata: Metadata produced by the compute_wrapper context manager
+        raise_error: Raise an exception if errors exist (True) or return FailedOperation (False)
+        return_dict: Return dictionary or object representation of data
+
     Returns
     -------
-    result : dict or pydantic.models.AtomicResult
+    result : AtomicResult, OptimizationResult, FailedOperation, or dict representation of any one.
         Output type depends on return_dict or a dict if an error was generated in model construction
     """
 
@@ -596,7 +602,9 @@ def disk_files(
         for fl, content in infiles.items():
             omode = "wb" if fl in as_binary else "w"
             filename = lwd / fl
-            with open(filename, omode) as fp:
+            if filename.parent != lwd:
+                filename.parent.mkdir(parents=True, exist_ok=True)
+            with filename.open(omode) as fp:
                 fp.write(content)
                 LOGGER.info(f"... Writing ({omode}): {filename}")
 
